@@ -2,7 +2,7 @@ module Dummy;
 use v6;
 
 sub load_test () is exported {
-  say "Module was loaded"
+  say "Module Dummy.pm was loaded"
 };
 
 1;
